@@ -2,6 +2,7 @@ from sanic import Blueprint
 
 from .datasource_properties import datasource_properties
 from .histogram import histogram
+from .meshes import meshes
 from .read_data import read_data
 from .thumbnail import thumbnail
 from .upload import upload
@@ -12,5 +13,6 @@ datasets = Blueprint.group(
     thumbnail,
     histogram,
     upload,
+    meshes,
     url_prefix="/datasets",
 )
